@@ -1,6 +1,7 @@
 package TestApp::View::TT;
 
-use base 'Catalyst::View::TT';
+eval "use base 'Catalyst::View::TT'";
+eval "use base 'Catalyst::View'" if $@;
 
 
 __PACKAGE__->config( INCLUDE_PATH => 't/lib/TestApp/tt' );
